## [0.3.0] - 2021-12-22


- Provides the ability to get the scan results in Dataframes. ([#99](https://github.com/sodadata/soda-spark/pull/99))
  - measurements
  - test_results
  - scan_errors
- Use version range for `soda-spark-sql` dependency
- Add `host` and `port` attributes to `_SparkDialect`

Contributors:
- [Anil Kulkarni](https://github.com/anilkulkarni87) ([#99](https://github.com/sodadata/soda-spark/pull/99))

## [0.2.3] - 2021-11-18

- Fix samples not working

## [0.2.1] - 2021-09-23

- Test and document sql metrics

## [0.2.0] - 2021-09-09

- Add option to connect with Soda cloud

## [0.1.1] - 2021-09-07

- Update documentation:
  - Add example for executing a scan with file
  - Explain how the `soda-spark` works
- Add change log

## [0.1.0] - 2021-09-06

- Implement Soda scan execute functionality
